@@ -22,6 +22,10 @@
 
 #define MYPROXY_DEFAULT_CLOCK_SKEW     300     /* 5 minutes */
 
+#define MYPROXY_CREDS_MAX_NAMELEN      80      /* longer names are
+                                                  hashed when used in
+                                                  filenames */
+
 /* myproxy client protocol information */
 /* beware no string below may be a suffix of another */
 #define MYPROXY_VERSION_STRING      "VERSION="
